@@ -17,6 +17,16 @@ class Base:
                        .get_output_streams()
     return streams
 
+  def _source_from_csv_common(self, stream_class, *args, **kwargs):
+
+    op = OperationHandler(self, stream_class)
+    streams = op.build_multilang_operation("source_from_csv", *args, **kwargs)\
+                       .add_operation_properties_to_info("name", "type")\
+                       .handle_operation()\
+                       .get_output_streams()
+    return streams
+
+
   def _call_component_common(self, input_stream, output_stream_class, *args, **kwargs):
     if len(args) == 1:
       kwargs["component_id"] = args[0]
