@@ -85,6 +85,19 @@ class Helper:
       msg = ee+"Invalid \"matches\" argument. When sourcing from a relation, please specify an SQL query-string or SXP query-array in \"matches\"."+pp
       self.print_error(msg)
 
+  @classmethod
+  def check_file(self, fname):
+    ee = "Error in \"source_from_csv\" at \"file\": \n\t "
+    pp = self.print_check_source_from_csv
+
+    try:
+      f = file(fname)
+      f.close()
+    except IOError:
+      msg = ee+"Invalid \"file\" argument: "+fname+". The specified file could not be found."+pp
+      self.print_error(msg)
+
+
   @classmethod
   def check_emits(self, operation, emits, streams):
     if operation == "component":
@@ -355,6 +368,19 @@ class Helper:
       * "begin_cycle_function" must take in a single argument (the "controller") and should return nothing. This is where any setup is done to initialize the content and quantity of tuples emitted by "next_tuple_function".
       * "next_tuple_function" must take in 2 arguments (the "controller" and the "tuple"), and should return nothing. This is where the tuples are actually emitted."""
 
+  print_check_source_from_csv = """\n
+"SourceFromCSV" Syntax:
+  Sourcing from a csv that does not include headers:
+    app.source_from_csv("csv_name", headers=["name", "email"] )
+
+  Sourcing from a csv that does include headers:
+    app.source_from_csv("csv_name")
+
+  - The "csv_name" is the path of the CSV within the app directory
+  - The "headers" field is a list of CSV field names ["field1", "field2"...]:
+  - The emitted output is a tuple hash {"field1" : value1, "field2" : value2},...}
+"""
+
   print_check_each = """\n
 "Each" Syntax:
 
