@@ -1,21 +1,16 @@
 class Tuple:
   def __init__(self, tup):
     self.values = tup["tuple"]
-    self.meta = tup["meta"]
     self.column_aliases = tup.get("column_aliases", [])
     self.alias_hash = None
 
   def __getitem__(self, k):
-    if k in self.meta:
-      return self.meta[k]
-    elif k in self.values:
+    if k in self.values:
       return self.values[k]
     self.maybe_build_alias_hash()
     concrete_name_to_get = self.alias_hash.get(k, None)
     concrete_name_to_get = concrete_name_to_get if concrete_name_to_get else k
-    if concrete_name_to_get in self.meta:
-      return self.meta[concrete_name_to_get]
-    elif concrete_name_to_get in self.values:
+    if concrete_name_to_get in self.values:
       return self.values[concrete_name_to_get]
     else:
       return None
